@@ -1,5 +1,5 @@
 package Test::Git;
-$Test::Git::VERSION = '1.313';
+$Test::Git::VERSION = '1.314';
 use strict;
 use warnings;
 
@@ -79,7 +79,7 @@ Test::Git - Helper functions for test scripts using Git
 
 =head1 VERSION
 
-version 1.313
+version 1.314
 
 =head1 SYNOPSIS
 
@@ -131,6 +131,9 @@ accepted by L<Git::Repository> and L<Git::Repository::Command>.
 This function must be called before C<plan()>, as it performs a B<skip_all>
 if requirements are not met.
 
+Note that the C<test_requires_git> function provided by the
+L<Test::Requires::Git> module is much more flexible.
+
 =head2 test_repository
 
     test_repository( %options );
@@ -209,6 +212,10 @@ The C<clone> option and capability of C<test_repository()> owes a lot
 to Nathan Nutter (NNUTTER), who wanted to be able to clone into a test
 repository.
 
+=head1 SEE ALSO
+
+L<Test::Requires::Git>.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
